==> AGXUnreal-1.17.0_UE-5.4_Win64.zip: Marketplace/AGXUnreal/Source/ThirdParty/agx/include/openplx/Physics3D/Interactions/Dissipation/PrismaticMechanicalDamping.h <==
#pragma once
#include <openplx/Object.h>
#include <openplx/ExpressionEvaluator.h>
#include <memory>
#include <stdexcept>
#include <unordered_map>
#include <openplx/Physics3D/Physics3DForward.h>
#include <openplx/Math/MathForward.h>
#include <openplx/Physics/PhysicsForward.h>
#include <openplx/Physics3D/Interactions/Dissipation/DefaultPrismaticDissipation.h>
#include <openplx/Physics/Interactions/Dissipation/MechanicalDamping.h>
/* Generated code for model PrismaticMechanicalDamping */
namespace openplx::Physics3D::Interactions::Dissipation {
    /**
     *     Defines mechanical damping for all constrained degrees of freedom for a Prismatic.
     *     */
    class PrismaticMechanicalDamping : public openplx::Physics3D::Interactions::Dissipation::DefaultPrismaticDissipation {
        protected:
            double m_default_damping;

        public:
            PrismaticMechanicalDamping();
            double default_damping() const;
            std::shared_ptr<openplx::Physics::Interactions::Dissipation::MechanicalDamping> along_normal() const;
            std::shared_ptr<openplx::Physics::Interactions::Dissipation::MechanicalDamping> along_cross() const;
            std::shared_ptr<openplx::Physics::Interactions::Dissipation::MechanicalDamping> around_main() const;
            std::shared_ptr<openplx::Physics::Interactions::Dissipation::MechanicalDamping> around_normal() const;
            std::shared_ptr<openplx::Physics::Interactions::Dissipation::MechanicalDamping> around_cross() const;
            void setDynamic(const std::string& key, openplx::Core::Any&& value) override;
            openplx::Core::Any getDynamic(const std::string& key) const override;
            openplx::Core::Any callDynamic(const std::string& key, const std::vector<openplx::Core::Any>& args) override;
            void extractObjectFieldsTo(std::vector<std::shared_ptr<openplx::Core::Object>>& output) const override;
            void extractEntriesTo(std::vector<std::pair<std::string, openplx::Core::Any>>& output) const override;
            void triggerOnInit(const openplx::RuntimeContext& context) override;
    };
}

==> AGXUnreal-2.1.1_UE-5.7_Win64.zip: Marketplace/AGXUnreal/Source/ThirdParty/agx/include/openplx/Physics3D/Interactions/Dissipation/PrismaticMechanicalDamping.h <==
#pragma once
#include <openplx/Object.h>
#include <openplx/ExpressionEvaluator.h>
#include <memory>
#include <stdexcept>
#include <unordered_map>
#include <openplx/Physics3D/Physics3DBundleExport.h>
#include <openplx/Physics3D/Physics3DForward.h>
#include <openplx/Math/MathForward.h>
#include <openplx/Physics/PhysicsForward.h>
#include <openplx/Physics3D/Interactions/Dissipation/DefaultPrismaticDissipation.h>
#include <openplx/Physics/Interactions/Dissipation/MechanicalDamping.h>

#ifdef _MSC_VER
#  pragma warning(push)
#  pragma warning(disable: 4251)
#endif

/* Generated code for model PrismaticMechanicalDamping */
namespace openplx::Physics3D::Interactions::Dissipation {
    /**
     *     Defines mechanical damping for all constrained degrees of freedom for a Prismatic.
     *     */
    class OPENPLX_Physics3D_BUNDLE_EXPORT PrismaticMechanicalDamping : public openplx::Physics3D::Interactions::Dissipation::DefaultPrismaticDissipation {
        protected:
            double m_default_damping;

        public:
            PrismaticMechanicalDamping();
            virtual ~PrismaticMechanicalDamping();
            double default_damping() const;
            std::shared_ptr<openplx::Physics::Interactions::Dissipation::MechanicalDamping> along_normal() const;
            std::shared_ptr<openplx::Physics::Interactions::Dissipation::MechanicalDamping> along_cross() const;
            std::shared_ptr<openplx::Physics::Interactions::Dissipation::MechanicalDamping> around_main() const;
            std::shared_ptr<openplx::Physics::Interactions::Dissipation::MechanicalDamping> around_normal() const;
            std::shared_ptr<openplx::Physics::Interactions::Dissipation::MechanicalDamping> around_cross() const;
            void setDynamic(const std::string& key, openplx::Core::Any&& value) override;
            openplx::Core::Any getDynamic(const std::string& key) const override;
            openplx::Core::Any callDynamic(const std::string& key, const std::vector<openplx::Core::Any>& args) override;
            void extractObjectFieldsTo(std::vector<std::shared_ptr<openplx::Core::Object>>& output) const override;
            void extractEntriesTo(std::vector<std::pair<std::string, openplx::Core::Any>>& output) const override;
            void triggerOnInit(const openplx::RuntimeContext& context) override;
    };
}

#ifdef _MSC_VER
#  pragma warning(pop)
#endif
